import { Component } from '@angular/core';
import { FormBuilder, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { MatButton } from '@angular/material/button';
import { MatFormField, MatLabel, MatSuffix } from '@angular/material/form-field';
import { MatIcon } from '@angular/material/icon';
import { MatInput } from '@angular/material/input';
import { ActivatedRoute } from '@angular/router';
import { Employee, EmployeeService } from '@core/ems';
import { Observable, of } from 'rxjs';

@Component({
    selector: 'app-employee-detail',
    imports: [
        MatButton,
        ReactiveFormsModule,
        MatFormField,
        MatLabel,
        MatInput,
        MatIcon,
        MatSuffix
    ],
    templateUrl: './employee-detail.component.html',
    styleUrl: './employee-detail.component.scss'
})
export class EmployeeDetailComponent {
    isNewEmployee: boolean;
    employeeForm: FormGroup;
    constructor(private route: ActivatedRoute, private employeeService: EmployeeService, private formBuilder: FormBuilder) {
        const idParam = this.route.snapshot.paramMap.get('id');
        this.isNewEmployee = idParam == null;

        this.employeeForm = this.formBuilder.group<Employee>({
            id: 0,
            firstName: '',
            lastName: '',
            postcode: '',
            city: '',
            street: '',
            phone: '',
            skillSet: []
        });

        if (this.isNewEmployee) {
            return;
        }

        const id = parseInt(idParam as string);
        this.employeeService.getEmployee({ id }).subscribe((employee) => {
            this.employeeForm = this.formBuilder.group<Employee>(employee);
        });



    }

    onAbort() {

    }

    onCreate() {

    }

    onSave() {

    }
}
